@@ -181,7 +181,7 @@ DEFAULT_CLI_ARGS = {
             ("--project-dir",),
             dict(
                 help="optional path for the location of the playbook content directory "
-                     "(default=<private_data_dir/project)"
+                     "(default=<private_data_dir>/project)"
             ),
         ),
         (
@@ -328,54 +328,6 @@ DEFAULT_CLI_ARGS = {
                      "to prevent multiple simultaneous executions from conflicting "
                      "(default=None)"
             )
-        ),
-        (
-            ("--resource-profiling",),
-            dict(
-                dest='resource_profiling',
-                action="store_true",
-                help="Records resource utilization during playbook execution"
-            )
-        ),
-        (
-            ("--resource-profiling-base-cgroup",),
-            dict(
-                dest='resource_profiling_base_cgroup',
-                default="ansible-runner",
-                help="Top-level cgroup used to collect information on resource utilization. Defaults to ansible-runner"
-            )
-        ),
-        (
-            ("--resource-profiling-cpu-poll-interval",),
-            dict(
-                dest='resource_profiling_cpu_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between CPU polling for determining CPU usage. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-memory-poll-interval",),
-            dict(
-                dest='resource_profiling_memory_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between memory polling for determining memory usage. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-pid-poll-interval",),
-            dict(
-                dest='resource_profiling_pid_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between polling PID count for determining number of processes used. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-results-dir",),
-            dict(
-                dest='resource_profiling_results_dir',
-                help="Directory where profiling data files should be saved. "
-                     "Defaults to None (profiling_data folder under private data dir is used in this case)."
-            )
         )
     ),
     "modules_group": (
@@ -659,11 +611,28 @@ def main(sys_args=None):
             "Using this will also assure that the directory is deleted when the job finishes."
         )
     )
+    worker_subparser.add_argument(
+        "--keepalive-seconds",
+        dest="keepalive_seconds",
+        default=None,
+        type=int,
+        help=(
+            "Emit a synthetic keepalive event every N seconds of idle. (default=0, disabled)"
+        )
+    )
     process_subparser = subparser.add_parser(
         'process',
         help="Receive the output of remote ansible-runner work and distribute the results"
     )
     add_args_to_parser(process_subparser, DEFAULT_CLI_ARGS['positional_args'])
+    process_subparser.add_argument(
+        "-i", "--ident",
+        default=None,
+        help=(
+            "An identifier to use as a subdirectory when saving artifacts. "
+            "Generally intended to match the --ident passed to the transmit command."
+        )
+    )
 
     # generic args for all subparsers
     add_args_to_parser(run_subparser, DEFAULT_CLI_ARGS['generic_args'])
@@ -757,7 +726,7 @@ def main(sys_args=None):
     # container group
     container_group_options = (
         "Ansible Container Options",
-        "configuation options for executing Ansible playbooks",
+        "configuration options for executing Ansible playbooks",
     )
     run_container_group = run_subparser.add_argument_group(*container_group_options)
     start_container_group = start_subparser.add_argument_group(*container_group_options)
@@ -895,16 +864,11 @@ def main(sys_args=None):
                                    container_volume_mounts=vargs.get('container_volume_mounts'),
                                    container_options=vargs.get('container_options'),
                                    directory_isolation_base_path=vargs.get('directory_isolation_base_path'),
-                                   resource_profiling=vargs.get('resource_profiling'),
-                                   resource_profiling_base_cgroup=vargs.get('resource_profiling_base_cgroup'),
-                                   resource_profiling_cpu_poll_interval=vargs.get('resource_profiling_cpu_poll_interval'),
-                                   resource_profiling_memory_poll_interval=vargs.get('resource_profiling_memory_poll_interval'),
-                                   resource_profiling_pid_poll_interval=vargs.get('resource_profiling_pid_poll_interval'),
-                                   resource_profiling_results_dir=vargs.get('resource_profiling_results_dir'),
                                    cmdline=vargs.get('cmdline'),
                                    limit=vargs.get('limit'),
                                    streamer=streamer,
                                    suppress_env_files=vargs.get("suppress_env_files"),
+                                   keepalive_seconds=vargs.get("keepalive_seconds"),
                                    )
                 try:
                     res = run(**run_options)
@@ -933,3 +897,7 @@ def main(sys_args=None):
             return 0
         except OSError:
             return 1
+
+
+if __name__ == '__main__':
+    sys.exit(main())
